/*
 *
 *  Request the remote name of an incoming HCI connection
 *
 *  Copyright (C) 2003  Marcel Holtmann <marcel@holtmann.org>
 *
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <stdio.h>
#include <errno.h>
#include <unistd.h>
#include <signal.h>
#include <sys/poll.h>
#include <sys/socket.h>

#include <bluetooth/bluetooth.h>
#include <bluetooth/hci.h>
#include <bluetooth/hci_lib.h>


static void inquiry(int dd, int len, int numrsp)
{
	inquiry_cp cp;

	memset(&cp, 0, sizeof(cp));
	cp.lap[0] = 0x33;
	cp.lap[1] = 0x8b;
	cp.lap[2] = 0x9e;
    cp.length = len;
    cp.num_rsp = numrsp;

	hci_send_cmd(dd, OGF_LINK_CTL, OCF_INQUIRY,
				INQUIRY_CP_SIZE, &cp);
}


int main(int argc, char *argv[])
{
	struct sigaction sa;
	int dd, dev = 0, len, numrsp;

    if (argc < 3)
    {
        printf("Usage:\ninquiry <length> <numrsp>\nwhere:\n");
        printf("    length: Inquiry length in 1.28s units (min. 1, max. 48)\n");
        printf("    numrsp: Number of Responses (0 == unlimited, max. 255)\n\n");
        return 1;
    }

    len = atoi(argv[1]);
    numrsp = atoi(argv[2]);
    
	dd = hci_open_dev(dev);
	if (dd < 0) {
		perror("Can't open HCI device");
		exit(1);
	}

    inquiry(dd, len, numrsp);

	if (hci_close_dev(dd) < 0) {
		perror("Can't close HCI device");
		exit(1);
	}

	return 0;
}
