/*
 *
 *  Request the remote name of an incoming HCI connection
 *
 *  Copyright (C) 2003  Marcel Holtmann <marcel@holtmann.org>
 *
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <stdio.h>
#include <errno.h>
#include <unistd.h>
#include <signal.h>
#include <sys/poll.h>
#include <sys/socket.h>

#include <bluetooth/bluetooth.h>
#include <bluetooth/hci.h>
#include <bluetooth/hci_lib.h>


static void name_req(int dd, char* addr)
{
	remote_name_req_cp cp;
    bdaddr_t* bdaddr;

	memset(&cp, 0, sizeof(cp));
	cp.pscan_rep_mode = 0;
	cp.pscan_mode = 0;
	cp.clock_offset = 0;
    bdaddr = strtoba(addr);
    baswap(&cp.bdaddr, bdaddr);
    free(bdaddr);

	hci_send_cmd(dd, OGF_LINK_CTL, OCF_REMOTE_NAME_REQ,
				REMOTE_NAME_REQ_CP_SIZE, &cp);
}


int main(int argc, char *argv[])
{
	struct sigaction sa;
	int dd, dev = 0;

    if (argc < 2)
    {
        printf("Usage:\nname_req <bd_addr>\nwhere:\n");
        printf("    bd_addr: The BD_ADDR of the device to be queried\n\n");
        return 1;
    }

	dd = hci_open_dev(dev);
	if (dd < 0) {
		perror("Can't open HCI device");
		exit(1);
	}

    name_req(dd, argv[1]);

	if (hci_close_dev(dd) < 0) {
		perror("Can't close HCI device");
		exit(1);
	}

	return 0;
}
